<?php

/* --------
   GLOBAL RESETS, ETC.
   --------
*/

// This theme uses post thumbnails
add_theme_support('post-thumbnails');

// Add default posts and comments RSS feed links to head
add_theme_support('automatic-feed-links');

// Remove WordPress version number generator
function cpt_remove_wp_version() {
	return '';
}
add_filter('the_generator', 'cpt_remove_wp_version');

// Add extra size for billboards and billboard thumbnail
add_image_size('cpt_billboard_main', 860, 410, true);
add_image_size('cpt_billboard_thumb', 80, 60, true);

// Add extra size for page banners
add_image_size('cpt_page_banner', 940, 100, true);

// Remove the [...] from the auto-generated excerpts
function cpt_excerpt_more($more) {
	return ' &hellip;';
}
add_filter('excerpt_more', 'cpt_excerpt_more');

// Disables the on-page ID jump on the single view 
// upon clicking from the index view.
// REF: http://codex.wordpress.org/Customizing_the_Read_More

function remove_more_jump_link($link) { 
	$offset = strpos($link, '#more-');
	
	if ($offset) {
		$end = strpos($link, '"',$offset);
	}
	
	if ($end) {
		$link = substr_replace($link, '', $offset, $end-$offset);
	}
	
	return $link;
}

add_filter('the_content_more_link', 'remove_more_jump_link');


/* --------
   MEDIA UPLOADER
   - Add extra scripts and styles to use the built-in media editor
   
   REF: http://www.webmaster-source.com/2010/01/08/using-the-wordpress-uploader-in-your-plugin-or-theme/
   --------
*/

function cpt_file_upload_scripts() {
	wp_enqueue_script('media-upload');
	wp_enqueue_script('thickbox');
	$cpt_file_upload_scripts_dir = get_stylesheet_directory_uri() . '/js/cpt-file-upload-scripts.js';
	wp_register_script('cpt_info_logo_upload_scripts', $cpt_file_upload_scripts_dir, array('jquery', 'media-upload', 'thickbox'));
	wp_enqueue_script('cpt_info_logo_upload_scripts');
}

function cpt_file_upload_styles() {
	wp_enqueue_style('thickbox');
}

// Call them on the options page
if (isset($_GET['page']) && $_GET['page'] == 'theme_options') {
	add_action('admin_print_scripts', 'cpt_file_upload_scripts');
	add_action('admin_print_styles', 'cpt_file_upload_styles');
}

// Call them on the sermon post type
if ((isset($_GET['post_type']) && $_GET['post_type'] == 'cpt_sermons') || (isset($_GET['post']))) {
	add_action('admin_print_scripts', 'cpt_file_upload_scripts');
	add_action('admin_print_styles', 'cpt_file_upload_styles');
}


/* --------
   THEME OPTIONS
   
   REF: http://themeshaper.com/2010/06/03/sample-theme-options/
   --------
*/

// Load theme options
require_once(get_template_directory() . '/theme-options.php');

// Add extra style sheet for the theme options page
function theme_options_add_styles() {
	$cpt_theme_options_stylesheet_path = get_template_directory_uri() . '/css/theme-options.css';
	wp_enqueue_style('theme_options_style', $cpt_theme_options_stylesheet_path, false, false, 'all'); 
}
add_action('admin_init', 'theme_options_add_styles');


/* --------
   REGISTER CUSTOM TAXONOMIES
   --------
*/

// Custom taxonomy for portfolio clients
add_action('init', 'cpt_register_taxonomies');

function cpt_register_taxonomies()
{
	register_taxonomy('cpt_bible_books',
		'cpt_sermons',
		array(
			'labels' => array(
				'name' => 'Books of the Bible',
				'singular_name' => 'Book',
				'search_items' => 'Search Books',
				'popular_items' => 'Popular Books',
				'all_items' => 'All Books',
				'parent_item' => 'Parent Book',
				'parent_item_colon' => 'Parent Book:',
				'edit_item' => 'Edit Book',
				'update_item' => 'Update Book',
				'add_new_item' => 'Add New Book',
				'new_item_name' => 'New Book Name'
			),
			'hierarchical' => true,
			'rewrite' => array('slug' => 'bible/book', 'with_front' => false),
		)
	);
	
	register_taxonomy('cpt_sermon_series',
		'cpt_sermons',
		array(
			'labels' => array(
				'name' => 'Sermon Series',
				'singular_name' => 'Portfolio Type',
				'search_items' => 'Search Sermon Series',
				'popular_items' => 'Popular Sermon Series',
				'all_items' => 'All Sermon Series',
				'parent_item' => 'Parent Sermon Series',
				'parent_item_colon' => 'Parent Sermon Series:',
				'edit_item' => 'Edit Sermon Series',
				'update_item' => 'Update Sermon Series',
				'add_new_item' => 'Add New Sermon Series',
				'new_item_name' => 'New Sermon Series Name'
			),
			'hierarchical' => true,
			'rewrite' => array('slug' => 'series', 'with_front' => false)
		)
	);
	
	/* --------
	   Prepopulate books of the Bible 
	   - This function loops through the array and creates the initial books of the Bible.
	   - You can add or edit these in the admin.
	*/
	
	$cpt_bible_books = array(
		array('genesis', 'Genesis'),
		array('exodus', 'Exodus'),
		array('leviticus', 'Leviticus'),
		array('numbers', 'Numbers'),
		array('deuteronomy', 'Deuteronomy'),
		array('joshua', 'Joshua'),
		array('judges', 'Judges'),
		array('ruth', 'Ruth'),
		array('1-samuel', '1 Samuel'),
		array('2-samuel', '2 Samuel'),
		array('1-kings', '1 Kings'),
		array('2-kings', '2 Kings'),
		array('1-chronicles', '1 Chronicles'),
		array('2-chronicles', '2 Chronicles'),
		array('ezra', 'Ezra'),
		array('nehemiah', 'Nehemiah'),
		array('esther', 'Esther'),
		array('job', 'Job'),
		array('psalms', 'Psalms'),
		array('proverbs', 'Proverbs'),
		array('ecclesiastes', 'Ecclesiastes'),
		array('song-of-songs', 'Song of Songs'),
		array('isaiah', 'Isaiah'),
		array('jeremiah', 'Jeremiah'),
		array('lamentations', 'Lamentations'),
		array('ezekiel', 'Ezekiel'),
		array('daniel', 'Daniel'),
		array('hosea', 'Hosea'),
		array('joel', 'Joel'),
		array('amos', 'Amos'),
		array('obadiah', 'Obadiah'),
		array('jonah', 'Jonah'),
		array('micah', 'Micah'),
		array('nahum', 'Nahum'),
		array('habakkuk', 'Habakkuk'),
		array('zephaniah', 'Zephaniah'),
		array('haggai', 'Haggai'),
		array('zechariah', 'Zechariah'),
		array('malachi', 'Malachi'),
		array('matthew', 'Matthew'),
		array('mark', 'Mark'),
		array('luke', 'Luke'),
		array('john', 'John'),
		array('acts', 'Acts'),
		array('romans', 'Romans'),
		array('1-corinthians', '1 Corinthians'),
		array('2-corinthians', '2 Corinthians'),
		array('galatians', 'Galatians'),
		array('ephesians', 'Ephesians'),
		array('philippians', 'Philippians'),
		array('colossians', 'Colossians'),
		array('1-thessalonians', '1 Thessalonians'),
		array('2-thessalonians', '2 Thessalonians'),
		array('1-timothy', '1 Timothy'),
		array('2-timothy', '2 Timothy'),
		array('titus', 'Titus'),
		array('philemon', 'Philemon'),
		array('hebrews', 'Hebrews'),
		array('james', 'James'),
		array('1-peter', '1 Peter'),
		array('2-peter', '2 Peter'),
		array('1-john', '1 John'),
		array('2-john', '2 John'),
		array('3-john', '3 John'),
		array('jude', 'Jude'),
		array('revelation', 'Revelation')
	);
	
	foreach($cpt_bible_books as $cpt_bible_book) {
		$cpt_has_book = get_term_by('slug', $cpt_bible_book[0], 'cpt_bible_books');
		
		// Only create it if it doesn't exist
		if (!$cpt_has_book) {
			wp_insert_term(
				$cpt_bible_book[1],
				'cpt_bible_books',
				array(
					'description' => '',
					'slug' => $cpt_bible_book[0]
				)
			);
		}
	}
	
	
	/* --------
	   Prepopulate the categories we will need 
	NOT SURE WHY NOT WORKING
	
	$cpt_categories = array(
		array('featured', 'Featured')
	);
	
	foreach($cpt_categories as $cpt_category) {
		$cpt_category = get_term_by('slug', $cpt_category[0], 'category');
		
		// Only create it if it doesn't exist
		if (!$cpt_category) {
			wp_insert_term(
				$cpt_category[1],
				'category',
				array(
					'description' => '',
					'slug' => $cpt_category[0]
				)
			);
		}
	}*/
}


/* --------
   REGISTER CUSTOM POST TYPES
   --------
*/

add_action('init', 'cpt_custom_post_types');

function cpt_custom_post_types()
{
	register_post_type('cpt_sermons',
		array(
			'labels' => array(
				'name' => 'Sermons',
				'singular_name' => 'Sermon',
				'add_new' => 'Add New Sermon',
				'add_new_item' => 'Add New Sermon',
				'edit' => 'Edit Sermons',
				'edit_item' => 'Edit Sermon',
				'new_item' => 'New Sermon',
				'view' => 'View Sermons',
				'view_item' => 'View Sermon',
				'search_items' => 'Search Sermons',
				'not_found' => 'No sermons were found.',
				'not_found_in_trash' => 'No sermons were found in the trash.',
				'parent' => 'Parent Sermon'
			),
			'description' => 'Add sermons to the site.',
			'public' => true,
			'menu_position' => 5,
			'hierarchical' => false,
			'query_var' => true,
			'supports' => array(
				'title',
				'editor',
				'revisions',
				'author',
				'excerpt',
				'thumbnail',
				'custom-fields',
				'comments'
			),
			'rewrite' => array('slug' => 'sermon', 'with_front' => false),
			'has_archive' => 'true',
			'taxonomies' => array('cpt_bible_books', 'cpt_sermon_series', 'category')
		)
	);
	
	register_post_type('cpt_billboards',
		array(
			'labels' => array(
				'name' => 'Billboards',
				'singular_name' => 'Billboard',
				'add_new' => 'Add New Billboard',
				'add_new_item' => 'Add New Billboard',
				'edit' => 'Edit Billboards',
				'edit_item' => 'Edit Billboard',
				'new_item' => 'New Billboard',
				'view' => 'View Billboards',
				'view_item' => 'View Billboard',
				'search_items' => 'Search Billboards',
				'not_found' => 'No billboards were found.',
				'not_found_in_trash' => 'No billboards were found in the trash.',
				'parent' => 'Parent Billboard'
			),
			'description' => 'Add billboards to the site.',
			'public' => true,
			'exclude_from_search' => true,
			'menu_position' => 6,
			'hierarchical' => false,
			'query_var' => true,
			'supports' => array(
				'title',
				'excerpt',
				'thumbnail'
			),
			'rewrite' => array('slug' => 'billboard', 'with_front' => false)
		)
	);
}


// Add custom post types to tags/categories
function query_post_type($query)
{
	if (is_category() || is_tag())
	{
		$post_type = get_query_var('post_type');
		
		if($post_type)
		    $post_type = $post_type;
		else
		    $post_type = array('post');
		
		$query->set('post_type',$post_type);
		return $query;
	}
}
add_filter('pre_get_posts', 'query_post_type');


/* --------
   ADD FIELD FOR IMAGE IN CUSTOM TAXONOMIES
   
   REF: http://en.bainternet.info/2011/custom-taxonomies-extra-fields
   --------
*/

add_action('cpt_sermon_series_edit_form_fields', 'cpt_extra_taxonomy_fields', 10, 2);

function cpt_extra_taxonomy_fields($tag) {
	$cpt_term_id = $tag->term_id;
	$cpt_term_id_get = 'taxonomy_' . $cpt_term_id;
  $cpt_term_meta = get_option($cpt_term_id_get);
  
  // Set null values if they don't exist
	$cpt_term_image_url = isset($cpt_term_meta['cpt_term_image_url']) ? ($cpt_term_meta['cpt_term_image_url']) : '';
	$cpt_term_current_series = isset($cpt_term_meta['cpt_term_current_series']) ? ($cpt_term_meta['cpt_term_current_series']) : '';
?>
	<tr class="form-field">
	<th scope="row" valign="top">Upload an image for this series</th>
	<td>	
		<label class="description" for="cpt_term_image_url">Upload an image (PNG, JPG or GIF) or paste in the URL.</label>
		<input id="cpt_term_image_url" class="cpt-file-upload" type="text" size="36" name="cpt_term_meta[cpt_term_image_url]" value="<?php esc_attr_e($cpt_term_image_url); ?>" />
		<input id="cpt_term_image_url_button" class="cpt-file-upload-button" type="button" value="Upload Image" style="width:200px;" />
		<p class="cpt-microcopy">After you have uploaded the image click the "Insert into post" button. (<a href="#">Help?</a>)</p>
	</td>
	</tr>
	<tr class="form-field">
	<th scope="row" valign="top">Status</th>
	<td>	
		<label for="cpt_term_current_series">
			Current series?
		</label>
		<select name="cpt_term_current_series">
			<?php
				$selected = $cpt_term_current_series;
			?>
			
			<option style="padding-right:10px;" <?php if ($selected == 'current-series') echo 'selected="selected"'; ?> value="current-series">Yes</option>
			<option style="padding-right:10px;" <?php if ($selected != 'current-series') echo 'selected="selected"'; ?> value="not-current-series">No</option>
		</select>
	</td>
	</tr>		
<?php
}

add_action('edited_cpt_sermon_series', 'cpt_extra_taxonomy_fields_save', 10, 2);

function cpt_extra_taxonomy_fields_save($term_id) {
	if (isset($_POST['cpt_term_meta'])) {
		$cpt_term_id_get = 'taxonomy_' . $term_id;
	  $cpt_term_meta = get_option($cpt_term_id_get);

		$cat_keys = array_keys($_POST['cpt_term_meta']);
		
		foreach ($cat_keys as $key) {
			if (isset($_POST['cpt_term_meta'][$key])) {
				$cpt_term_meta[$key] = $_POST['cpt_term_meta'][$key];
			}
		}
		
		$cpt_term_meta['cpt_term_current_series'] = $_POST['cpt_term_current_series'];
		
		//save the option array
		update_option($cpt_term_id_get, $cpt_term_meta);
	}
}


/* --------
   ADD CUSTOM META BOX FOR SERMONS
   --------
*/

// Adds the custom field box
add_action('admin_menu', 'cpt_add_custom_fields');

function cpt_add_custom_fields() {
	add_meta_box('cpt_sermon_details_add_box', 'Sermon Details', 'cpt_sermon_details_meta_box', 'cpt_sermons', 'normal', 'low');
}

// Adds custom meta UI to the Add New Sermon interface
function cpt_sermon_details_meta_box($post) {
	//Use nonce for verification
	$cpt_sermon_meta_nonce = wp_create_nonce(basename(__FILE__));

	//$cpt_sermon_preached_on = get_post_meta($post->ID, 'cpt_sermon_preached_on', true);
	$cpt_sermon_meta_scripture = get_post_meta($post->ID, 'cpt_sermon_meta_scripture', true);
	$cpt_sermon_meta_main_notes_link = get_post_meta($post->ID, 'cpt_sermon_meta_main_notes_link', true);
	//$cpt_sermon_meta_main_devo_link = get_post_meta($post->ID, 'cpt_sermon_meta_main_devo_link', true);
	$cpt_sermon_meta_video = get_post_meta($post->ID, 'cpt_sermon_meta_video', true);
	//$cpt_sermon_meta_artwork = get_post_meta($post->ID, 'cpt_sermon_meta_artwork', true);
?>
	<input type="hidden" name="cpt_sermon_meta_nonce" id="cpt_sermon_meta_nonce" value="<?php echo $cpt_sermon_meta_nonce; ?>" />

	<p>Enter the sermon details below; don&#8217;t forget to click the <strong>Update Post</strong> button to save.</p>
	<?php /*<p class="preform-custom-field-group">
		<label class="description" for="cpt_sermon_preached_on">Date preached on:</label>
		<input type="text" size="36" name="cpt_sermon_preached_on" value="<?php echo $cpt_sermon_preached_on; ?>" />
		<label for="cpt_sermon_use_preached_on">
			<input id="cpt_sermon_use_preached_on" name="cpt_sermon_use_preached_on" type="checkbox" value="UsePreachedOn"<?php if ($cpt_download_enclosure) echo ' checked="checked"'; ?> />
			Use this date instead of the published date
		</label>
	</p>*/ ?>
	<p class="preform-custom-field-group">
		<label class="description" for="cpt_sermon_meta_scripture">Sermon scripture reference:</label>
		<input type="text" size="36" name="cpt_sermon_meta_scripture" value="<?php echo $cpt_sermon_meta_scripture; ?>" />
	</p>
	<p class="preform-custom-field-group">
		<label class="description" for="cpt_sermon_meta_main_notes_link">Upload sermon notes (PDF)</label>
		<input id="cpt_sermon_meta_main_notes_link" class="cpt-file-upload" type="text" size="36" name="cpt_sermon_meta_main_notes_link" value="<?php echo $cpt_sermon_meta_main_notes_link; ?>" />
		<input id="cpt_sermon_meta_main_notes_link_button" class="cpt-file-upload-button" type="button" value="Upload File" />
	</p>
	<?php /*<p class="preform-custom-field-group">
		<label class="description" for="cpt_sermon_meta_main_devo_link">Upload related devotional (PDF)</label>
		<input id="cpt_sermon_meta_main_devo_link" class="cpt-file-upload" type="text" size="36" name="cpt_sermon_meta_main_devo_link" value="<?php echo $cpt_sermon_meta_main_devo_link; ?>" />
		<input id="cpt_sermon_meta_main_devo_link_button" class="cpt-file-upload-button" type="button" value="Upload File" />
	</p>
	<p class="preform-custom-field-group">
		<label class="description" for="cpt_sermon_meta_artwork">Sermon artwork (JPG, PNG, GIF)</label>
		<input id="cpt_sermon_meta_artwork" class="cpt-file-upload" type="text" size="36" name="cpt_sermon_meta_artwork" value="<?php echo $cpt_sermon_meta_artwork; ?>" />
		<input id="cpt_sermon_meta_artwork_button" class="cpt-file-upload-button" type="button" value="Upload Image" />
	</p>*/ ?>
	<p class="preform-custom-field-group">
		<label class="description" for="cpt_sermon_meta_video">Sermon video embed code:</label>
		<textarea id="cpt_sermon_meta_video" name="cpt_sermon_meta_video" cols="60" rows="5"><?php echo $cpt_sermon_meta_video; ?></textarea>
		<span class="cpt-microcopy">If there is a video that is associated with this sermon then you can paste the embed code (i.e. Vimeo, YouTube, etc.) in the box above and it will appear on the sermon page.</span>
	</p>
	
	<?php	
		// WP stores enclosure length and type in same field
		// We'll just display the part that matters and hide the rest since it will be calculated on every save anyway
		// Besides, you cannot display a WP-style enclosure (with \n) in a text input
		$enclosure = get_post_meta($post->ID, 'enclosure', true);
		$enclosure = split("\n", $enclosure); // parse wp enclosure (url, length, and type separated by \n)
		$enclosure = trim(htmlspecialchars($enclosure[0])); // take and clean up first item
		$cpt_download_enclosure = get_post_meta($post->ID, 'cpt_download_enclosure', true);
	?>
	
	<p>Enter an mp3 link for podcast and to call the audio player for this post. The link can be either from another site or an internal link provided by WordPress once an mp3 is uploaded. Should be an absolute link (that is, begin with http://).</p>
	<input type="text" name="enclosure" value="<?php echo $enclosure; ?>" style="width:100%;" />
	<input type="hidden" name="sm2_nonce" id="sm2_nonce" value="<?php echo $sm2_nonce; ?>" />
	<label for="cpt_download_enclosure">
		<input id="cpt_download_enclosure" name="cpt_download_enclosure" type="checkbox" value="AllowDownload"<?php if ($cpt_download_enclosure) echo ' checked="checked"'; ?> />
		Allow people to download file.
	</label>
<?php
}

add_action('save_post', 'cpt_sermon_meta_save');

// Save Sermon meta data
function cpt_sermon_meta_save($post_id) {
	/* The save_post is triggered at the beginning returning an empty $_POST array.
	   This code checks to make sure the $_POST aray has data before we try to do
	   anything with it.
	   
	   REF: http://wordpress.stackexchange.com/questions/20059/why-is-save-post-triggered-even-when-i-havent-saved-the-post/20069#20069
	*/
	
	if ((defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) || !isset($_POST['cpt_sermon_meta_nonce']))
		return $post_id;
	
	// Verify this came from the our screen and with proper authorization,
	// Because save_post can be triggered at other times
	if (!wp_verify_nonce($_POST['cpt_sermon_meta_nonce'], basename(__FILE__))) {
		return $post_id;
	}
	
	if ('cpt_sermons' == $_POST['post_type']) {
		if (!current_user_can('edit_post', $post_id))
			return $post_id;
	}
	elseif ('page' == $_POST['post_type']) {
		if (!current_user_can('edit_page', $post_id))
			return $post_id;
	}
	else {
		if (!current_user_can('edit_post', $post_id))
			return $post_id;
	}
	
	// OK, we're authenticated: we need to find and save the data
	$cpt_sermon_meta_scripture = $_POST['cpt_sermon_meta_scripture'];
	$cpt_sermon_meta_main_notes_link = $_POST['cpt_sermon_meta_main_notes_link'];
	//$cpt_sermon_meta_main_devo_link = $_POST['cpt_sermon_meta_main_devo_link'];
	$cpt_sermon_meta_video = stripslashes($_POST['cpt_sermon_meta_video']);
	//$cpt_sermon_meta_artwork = $_POST['cpt_sermon_meta_artwork'];
	
	// SCRIPTURE REFERENCE
	if ($cpt_sermon_meta_scripture) {
		if (!update_post_meta($post_id, 'cpt_sermon_meta_scripture', $cpt_sermon_meta_scripture)) {
			add_post_meta($post_id, 'cpt_sermon_meta_scripture', $cpt_sermon_meta_scripture);
		}
	}
	else {
		delete_post_meta($post_id, 'cpt_sermon_meta_scripture');
	}
	
	// NOTES LINK
	if ($cpt_sermon_meta_main_notes_link) {
		if (!update_post_meta($post_id, 'cpt_sermon_meta_main_notes_link', $cpt_sermon_meta_main_notes_link)) {
			add_post_meta($post_id, 'cpt_sermon_meta_main_notes_link', $cpt_sermon_meta_main_notes_link);
		}
	}
	else {
		delete_post_meta($post_id, 'cpt_sermon_meta_main_notes_link');
	}
	
	/*
	// DEVOTIONAL LINK
	if ($cpt_sermon_meta_main_devo_link) {
		if (!update_post_meta($post_id, 'cpt_sermon_meta_main_devo_link', $cpt_sermon_meta_main_devo_link)) {
			add_post_meta($post_id, 'cpt_sermon_meta_main_devo_link', $cpt_sermon_meta_main_devo_link);
		}
	}
	else {
		delete_post_meta($post_id, 'cpt_sermon_meta_main_devo_link');
	}
	*/
	
	// VIDEO
	if ($cpt_sermon_meta_video) {
		if (!update_post_meta($post_id, 'cpt_sermon_meta_video', $cpt_sermon_meta_video)) {
			add_post_meta($post_id, 'cpt_sermon_meta_video', $cpt_sermon_meta_video);
		}
	}
	else {
		delete_post_meta($post_id, 'cpt_sermon_meta_video');
	}
	
	/*
	// ARTWORK
	if ($cpt_sermon_meta_artwork) {
		if (!update_post_meta($post_id, 'cpt_sermon_meta_artwork', $cpt_sermon_meta_artwork)) {
			add_post_meta($post_id, 'cpt_sermon_meta_artwork', $cpt_sermon_meta_artwork);
		}
	}
	else {
		delete_post_meta($post_id, 'cpt_sermon_meta_artwork');
	}
	*/
	
	// OK, we're authenticated: we need to find and save the data
	$enclosure = $_POST['enclosure'];
	$cpt_download_enclosure = $_POST['cpt_download_enclosure'];
	
	// Save if we have enclosure
	if ($enclosure) {
		// WP stores enclosure length and type in same field
		// Enclosure may have type and length already
		$enclosure = split("\n", $enclosure); // parse wp enclosure (url, length, and type separated by \n)
		$enclosure = trim(htmlspecialchars($enclosure[0])); 	// take and clean up first item

		// Get headers
		$headers = wp_get_http_headers($enclosure);
		
		/*// Test if valid enclosure ('OK' server response)
		if ($headers && $headers['response'] == '200') {
			// Build enclosure WP-style
			$length = (int) $headers['content-length'];
			$type = $headers['content-type'];
			$enclosure = "$enclosure\n$length\n$type\n";
		}*/

		// Add it if it can't update an existing enclosure
		if (!update_post_meta($post_id, 'enclosure', $enclosure)) {
			add_post_meta($post_id, 'enclosure', $enclosure);
		}
	}
	// Else delete (box is empty so person intended to remove enclosure)
	else {
		delete_post_meta($post_id, 'enclosure'); // will delete all enclosures for this post
	}

	// Hack. Removes hidden field which WP uses as a flag to later process enclosures.
	// WP's process will delete enclosures it doesn't find linked in post_content.
	// Feature? But we don't want an 'incidental' podcast.
	// This also will disable WP's auto-enclosing if media links are in posts.
	delete_post_meta($post_id, '_encloseme');
	
	// Download option
	if ($cpt_download_enclosure) {
		if (!update_post_meta($post_id, 'cpt_download_enclosure', $cpt_download_enclosure)) {
			add_post_meta($post_id, 'cpt_download_enclosure', $cpt_download_enclosure);
		}
	}
	else {
		delete_post_meta($post_id, 'cpt_download_enclosure');
	}
	
	return;
}
	
	
/* --------
   SETUP AND REGISTER AUDIO PLAYER
   
   - Typically this would be accomplished through a separate plugin. But in the interest
     of typical users I am including it by default.
   - The original code for this plugin was written by Chad Helmer.
   --------
*/

add_action('wp_head', 'sm2_wp_head');

function sm2_wp_head() {
?>
	<!-- SoundManager 2 -->
	<link rel="stylesheet" media="all" href="<?php bloginfo('template_url'); ?>/sound-manager-2/360-player/360player.css" /><!-- required -->	
	<!--[if IE]><script src="<?php bloginfo('template_url'); ?>/sound-manager-2/360-player/excanvas.js"></script><![endif]--><!-- special IE-only canvas fix -->
	<script src="<?php bloginfo('template_url'); ?>/sound-manager-2/360-player/berniecode-animator.js"></script><!-- Apache-licensed animation library -->
	<script src="<?php bloginfo('template_url'); ?>/sound-manager-2/soundmanager2.js"></script><!-- SoundManager 2 library -->
	<script src="<?php bloginfo('template_url'); ?>/sound-manager-2/360-player/360player.js"></script><!-- 360 Player core -->

	<?php
	/*
	// Inline Player. Takes over every mp3 link (unless "inline-exclude" class added to link)
	?>
	<link rel="stylesheet" type="text/css" href="<?php bloginfo('url'); ?>/wp-content/plugins/sound-manager-2/inline-player/inlineplayer.css" /><!-- required -->
	<script type="text/javascript" src="<?php bloginfo('url'); ?>/wp-content/plugins/sound-manager-2/inline-player/inlineplayer.js"></script><!-- Inline Player core -->
	<?php
	*/
	?>
	
	<!-- configure it for your use -->
	<script type="text/javascript">
	soundManager.consoleOnly = true;
	soundManager.debugMode = false;
	soundManager.url = '<?php bloginfo('template_url'); ?>/sound-manager-2/'; // path to directory containing SM2 SWF
	soundManager.flashVersion = 9; // default is 9
	soundManager.useHighPerformance = false;
	soundManager.wmode = 'transparent';
	soundManager.useHTML5Audio = true;
	threeSixtyPlayer.config = {
		playNext: false, // stop after one sound, or play through list until end
		autoPlay: false, // start playing the first sound right away
		loadRingColor: '#ccc',// amount of sound which has loaded
		playRingColor: '#df5d06', // amount of sound which has played
		backgroundRingColor: '#e8e8e8', // "default" color shown underneath everything else
		imageRoot: '<?php bloginfo('template_url'); ?>/sound-manager-2/360-player/',// path to prepend for empty.gif used for play/pause button
		animDuration: 500,
		animTransition: Animator.tx.bouncy // http://www.berniecode.com/writing/animator.html
	}
	</script>
	<!-- END SoundManager 2 -->	
<?php
}


// Template include for 360 player upon finding enclosure
function sm2_template() {
	global $post;
	
	// Possibly get all enclosures and take first mp3?
	$enclosure = get_post_meta($post->ID, 'enclosure', true);	// Expect one enclosure
	$enclosure = split("\n", $enclosure); // parse wp enclosure (url, length, and type separated by \n)
	$enclosure = trim(htmlspecialchars($enclosure[0])); // take and clean up first item
	
	/*
	NOTE:
	- I think this code no longer applies to the way WordPress is structured.
	- Leaving it here for reference though.
	- Also, I believe this leaves us without a way to check if it's a valid MP3 file.
	
	if ($enclosure[2]) {
		$enc_type = trim($enclosure[2]); // get mime type
	}
	else {
		// Try to get content type if not supplied
		$headers = wp_get_http_headers($enclosure);
		$enc_type = $headers['content-type'];
	}

	// Test if enclosure and if mp3 mime type
	// Display div, class and link that javascript is expecting
	//if ($enclosure && $enc_type == 'audio/mpeg') {
	*/
?>
	<div class="ui360 sm2_template">
		<a href="<?php echo $enclosure; ?>"></a>
	</div>
<?php
//	} - NOTE: Closes the $enc_type test.
}



/* --------
   DISPLAY SINGLE COMMENT
   - referenced in comments.php
   - This is from the Twenty Eleven theme
*/

if (!function_exists('cpt_comment')) {
	function cpt_comment($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment;
		switch ($comment->comment_type) :
			case 'pingback' :
			case 'trackback' :
		?>
		<li class="comment pingback">
			<p>
				<strong>Pingback</strong>: <?php comment_author_link(); ?>
				<?php edit_comment_link('Edit', '<span class="comment-edit-link">', '</span>'); ?>
			</p>
		<?php
				break;
			default :
		?>
		<li id="li-comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
			<article id="comment-<?php comment_ID(); ?>" class="comment">
				<footer class="comment-meta">
					<div class="comment-author vcard">
						<?php
							$avatar_size = 40;
							if ( '0' != $comment->comment_parent )
								$avatar_size = 30;
	
							echo get_avatar( $comment, $avatar_size );
	
							/* translators: 1: comment author, 2: date and time */
							printf('%1$s %2$s',
								sprintf('<span class="fn">%s</span>', get_comment_author_link()),
								sprintf('<a class="comment-pubdate" href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
									esc_url( get_comment_link($comment->comment_ID )),
									get_comment_time('c'),
									/* translators: 1: date, 2: time */
									sprintf('%1$s at %2$s', get_comment_date(), get_comment_time())
								)
							);
						?>
	
						<?php edit_comment_link('Edit', '<span class="comment-edit-link">', '</span>'); ?>
					</div><!-- .comment-author .vcard -->
	
					<?php if ( $comment->comment_approved == '0' ) : ?>
						<em class="comment-awaiting-moderation">Your comment is awaiting moderation.</em>
					<?php endif; ?>
	
				</footer>
	
				<div class="comment-content">
					<?php comment_text(); ?>
				</div>
	
				<div class="reply">
					<?php comment_reply_link(array_merge($args, array('reply_text' => 'Reply <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
				</div><!-- .reply -->
			</article><!-- #comment-## -->
	
		<?php
				break;
		endswitch;
	}
} // ends check for cpt_comment()


/* --------
   ADD EXTRA USER OPTIONS TO PROFILE
   
   This does the following:
   - Adds input fields and check boxes
   - Adds extra textarea for bio
   --------
*/

/* This function taps into the WP API to add/remove fields
   in the contact methods section of the user profile. */
   
function cpt_additional_user_contactmethods($contactmethods) {
	// Add these
	$contactmethods['twitter'] = 'Twitter username (no @ symbol)'; // Twitter
	$contactmethods['facebook'] = 'Facebook page website address'; // Facebook
	$contactmethods['office_number'] = 'Office number'; // Office Number
	$contactmethods['mobile_number'] = 'Mobile number'; // Mobile Number
	
	// Remove these
	unset($contactmethods['aim']);
	unset($contactmethods['yim']);
	unset($contactmethods['jabber']);
	
	return $contactmethods;
}

add_filter('user_contactmethods', 'cpt_additional_user_contactmethods', 10, 1);


/* This function manually adds extra fields to the user profile. */

add_action('show_user_profile', 'cpt_user_extra_meta');
add_action('edit_user_profile', 'cpt_user_extra_meta');

function cpt_user_extra_meta($user) {
	$cpt_position_title = esc_attr(get_the_author_meta('cpt_position_title', $user->ID));
	
	$cpt_is_user_leadership_team = get_the_author_meta('cpt_is_user_leadership_team', $user->ID);
	$cpt_is_user_staff = get_the_author_meta('cpt_is_user_staff', $user->ID);
?>
	<table class="form-table">
	<tr>
		<th>Position title</th>
		<td>
			<p>
				<input id="cpt_position_title" name="cpt_position_title" type="text" value="<?php if ($cpt_position_title) echo $cpt_position_title; ?>" />
			</p>
		</td>
	</tr>
	<tr>
		<th>Profile information</th>
		<td>
			<p>
				<label for="cpt_is_user_leadership_team">
					<input id="cpt_is_user_leadership_team" name="cpt_is_user_leadership_team" type="checkbox" value="Leadership Team"<?php if ($cpt_is_user_leadership_team) echo ' checked="checked"'; ?> />
					Leadership team
				</label>
				<label for="cpt_is_user_staff">
					<input id="cpt_is_user_staff" name="cpt_is_user_staff" type="checkbox" value="Staff"<?php if ($cpt_is_user_staff) echo ' checked="checked"'; ?> />
					Staff
				</label>
			</p>
		</td>
	</tr>
	</table>
<?php
}


/* This function manually saves the extra fields we added to the user profile. */

add_action('personal_options_update', 'cpt_user_extra_meta_save');
add_action('edit_user_profile_update', 'cpt_user_extra_meta_save');

function cpt_user_extra_meta_save($user_id) {
	if (!current_user_can('edit_user', $user_id))
		return false;
		
	update_user_meta($user_id, 'cpt_position_title', $_POST['cpt_position_title']);
	
	if (isset($_POST['cpt_is_user_leadership_team'])) {
		update_user_meta($user_id, 'cpt_is_user_leadership_team', $_POST['cpt_is_user_leadership_team']);
	}
	else {
		update_user_meta($user_id, 'cpt_is_user_leadership_team', '');
	}
	
	if (isset($_POST['cpt_is_user_staff'])) {
		update_user_meta($user_id, 'cpt_is_user_staff', $_POST['cpt_is_user_staff']);
	}
	else {
		update_user_meta($user_id, 'cpt_is_user_staff', '');
	}
}


/* --------
   ADD CUSTOM LINK CATEGORIES
   
   REF:
   http://premium.wpmudev.org/forums/topic/create-new-blog-default-link-categories
   --------
*/

$cpt_links_cats = array('Quick Links');

foreach ($cpt_links_cats as $cpt_links_cat) {
	$cat_name = trim($cpt_links_cat);
	$slug = sanitize_title($cat_name);
	
	if ('' === $slug)
		continue;
	if (!$cat_id = term_exists($cat_name, 'link_category')) {
		$cat_id = wp_insert_term($cat_name, 'link_category');
	}
}


/* --------
   ADD CUSTOM HEADER IMAGE UPLOAD FUNCTIONALITY
   --------


define('HEADER_TEXTCOLOR', '');
define('HEADER_IMAGE', trailingslashit(get_stylesheet_directory_uri()).'images/sample-header.jpg');
define('HEADER_IMAGE_WIDTH', 700);
define('HEADER_IMAGE_HEIGHT', 110);

define('NO_HEADER_TEXT', true);

// Outputs the extra CSS in the theme's <head>
function header_style() {
?>
	<style>.site-logo { background:url("<?php header_image(); ?>") 0 0 no-repeat; }</style>
<?php
}

// Adds necessary styles for the admin
function admin_header_style() {
?>
	<style>
		#headimg {
			width:<?php echo HEADER_IMAGE_WIDTH; ?>px;
			height:<?php echo HEADER_IMAGE_HEIGHT; ?>px;
			background-repeat:no-repeat;
		}
	</style>
<?php
}

// Activates the custom header image functionality
add_custom_image_header('header_style', 'admin_header_style');
*/


/* --------
   WIDGETS
   --------
*/

/* Build widget-enabled areas. */
function cpt_widgets_init() {
	register_sidebar( array(
		'name' => 'Blog Sidebar',
		'id' => 'cpt-blog-sidebar',
		'description' => 'Sidebar that appears on the blog pages.',
		'before_widget' => '<section class="sidebar-block %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h5 class="sidebar-label">',
		'after_title' => '</h5>',
	));
	
	register_sidebar( array(
		'name' => 'Home Page Featured Right',
		'id' => 'cpt-hp-mid-r',
		'description' => 'Below the main billboard area, on the right.',
		'before_widget' => '<section class="feature-block home-block %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h2 class="feature-block-title">',
		'after_title' => '</h2>',
	));
	
	register_sidebar( array(
		'name' => 'Home Page Bottom Left Column',
		'id' => 'cpt-hp-col-bl',
		'description' => 'In the bottom left of the home page.',
		'before_widget' => '<section class="home-block-col-bl home-block %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h5 class="home-block-label block-label"><span class="home-block-label-content block-label-content">',
		'after_title' => '</span></h5>',
	));
	
	register_sidebar( array(
		'name' => 'Home Page Bottom Middle Column',
		'id' => 'cpt-hp-col-bm',
		'description' => 'In the bottom middle of the home page.',
		'before_widget' => '<section class="home-block-col-bm home-block %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h5 class="home-block-label block-label"><span class="home-block-label-content block-label-content">',
		'after_title' => '</span></h5>',
	));
	
	register_sidebar( array(
		'name' => 'Home Page Bottom Right Column',
		'id' => 'cpt-hp-col-br',
		'description' => 'In the bottom left of the home page.',
		'before_widget' => '<section class="home-block-col-br home-block %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h5 class="home-block-label block-label"><span class="home-block-label-content block-label-content">',
		'after_title' => '</span></h5>',
	));
	
	register_sidebar( array(
		'name' => 'Footer Top Right',
		'id' => 'cpt-footer-ur',
		'description' => 'In the upper right of the footer.',
		'before_widget' => '<div class="footer-block-ur footer-block %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h5 class="footer-block-label block-label"><span class="footer-block-label-content block-label-content">',
		'after_title' => '</span></h5>',
	));
	
	register_sidebar( array(
		'name' => 'Footer Bottom Right',
		'id' => 'cpt-footer-lr',
		'description' => 'In the lower right of the footer.',
		'before_widget' => '<div class="footer-block-lr footer-block %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h5 class="footer-block-label block-label"><span class="footer-block-label-content block-label-content">',
		'after_title' => '</span></h5>',
	));
}

/* Register widget-enabled areas. */
add_action('widgets_init', 'cpt_widgets_init');


/* --------
   ADDING CUSTOM WIDGETS
   - Adds extra custom widgets
   - Code copied and changed from wp-includes/default-widgets.php
   
   REF: http://wordpress.stackexchange.com/questions/2405/including-custom-post-types-in-recent-posts-widget
   --------
*/


/* WIDGET: Display recent sermons */

add_action('widgets_init', create_function('',"register_widget('WP_Widget_Recent_Sermons');"));

class WP_Widget_Recent_Sermons extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_recent_sermon_entries', 'description' => __( "Display a list of the most recent sermons.") );
		parent::__construct('recent-sermons', __('Recent Sermons'), $widget_ops);
		$this->alt_option_name = 'widget_recent_sermon_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_recent_sermons', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Sermons') : $instance['title'], $instance, $this->id_base);
		if ( ! $number = absint( $instance['number'] ) )
 			$number = 10;

		$r = new WP_Query(array('post_type' => 'cpt_sermons', 'posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true));
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>

		<?php while ($r->have_posts()) : $r->the_post(); ?>
			
		<?php
			$cpt_sermon_meta_scripture = get_post_meta(get_the_ID(), 'cpt_sermon_meta_scripture', true);
			$cpt_sermon_meta_main_notes_link = get_post_meta(get_the_ID(), 'cpt_sermon_meta_main_notes_link', true);
			//$cpt_sermon_meta_main_devo_link = get_post_meta(get_the_ID(), 'cpt_sermon_meta_main_devo_link', true);
			//$cpt_sermon_meta_video = get_post_meta(get_the_ID(), 'cpt_sermon_meta_video', true);
			//$cpt_sermon_meta_artwork = get_post_meta(get_the_ID(), 'cpt_sermon_meta_artwork', true);
			$cpt_download_enclosure = get_post_meta(get_the_ID(), 'cpt_download_enclosure', true);
			
			$cpt_sermon_series = get_the_terms(get_the_ID(), 'cpt_sermon_series');
			$cpt_scripture = get_the_terms(get_the_ID(), 'cpt_bible_books');
		?>
			<section class="st-sermon t-sermon t-post">
				<?php /* REMOVING FOR WIDGETS
				<div class="s-primary">
					<?php
						// Output radial audio player
						if (function_exists('sm2_template')) { sm2_template(); }
					?>
					
					<?php
						if ($cpt_download_enclosure == "AllowDownload") {
							$enclosure = get_post_meta(get_the_ID(), 'enclosure', true);	// Expect one enclosure
							$enclosure = split("\n", $enclosure); // parse wp enclosure (url, length, and type separated by \n)
							$enclosure = trim(htmlspecialchars($enclosure[0])); // take and clean up first item
					?>
							<a class="download-audio download-link" href="<?php echo $enclosure; ?>" title="Download this file">Download</a>
					<?php
						}
					?>
					
					<?php if ($cpt_sermon_meta_main_notes_link) { ?><a class="download-sermon-notes download-link" href="<?php echo $cpt_sermon_meta_main_notes_link; ?>" title="Download sermon notes">Download sermon notes</a> <?php } ?>
					
					<?php if ($cpt_sermon_meta_main_devo_link) { ?> <a class="download-sermon-devotional download-link" href="<?php echo $cpt_sermon_meta_main_devo_link; ?>" title="Download sermon devotional">Download sermon devotional</a> <?php } ?>
				</div>
				*/ ?>
				
				<header class="st-header s-header">
					<h1 class="st-title s-title"><a class="p-title-link" href="<?php the_permalink(); ?>" title="Go to the permalink page for this sermon."><?php the_title(); ?></a></h1>
					<p class="s-byline"><span class="s-byline-label">By</span> <strong class="p-author"><?php the_author_posts_link(); ?></strong></p>
					<p class="s-byline"><time class="p-publish-date" datetime="<?php the_time('Y-m-d'); ?>" pubdate><?php the_time('l, F j, Y'); ?></time></p>
					
					<?php if ($cpt_sermon_series) { ?>
					<p class="s-byline">
						<span class="s-byline-label">Sermon Series</span>
						<?php
							foreach ($cpt_sermon_series as $cpt_ss) {
						?>
							<a class="s-series-link" href="<?php bloginfo('url'); ?>/series/<?php echo $cpt_ss->slug; ?>"><?php echo $cpt_ss->name; ?></a>
						<?php
							}
						?>
					</p>
					<?php } ?>
					
					<?php if ($cpt_scripture) { ?>
					<p class="s-byline">
						<span class="s-byline-label">Scripture</span>
						<?php
							foreach ($cpt_scripture as $cpt_bb) {
						?>
							<a class="s-scripture-link" href="<?php bloginfo('url'); ?>/bible/book/<?php echo $cpt_bb->slug; ?>"><?php echo $cpt_bb->name; ?></a>
						<?php
							}
						?>
					</p>
					<?php } ?>
					
					<?php
						if ($cpt_download_enclosure == "AllowDownload") {
							$enclosure = get_post_meta($post->ID, 'enclosure', true);	// Expect one enclosure
							$enclosure = split("\n", $enclosure); // parse wp enclosure (url, length, and type separated by \n)
							$enclosure = trim(htmlspecialchars($enclosure[0])); // take and clean up first item
					?>
							<p class="s-byline-audio s-byline">
								<a class="download-sermon-notes download-link" href="<?php echo $enclosure; ?>" title="Download this sermon">Download sermon</a> 
							</p>
					<?php
						}
					?>
					<?php if ($cpt_sermon_meta_main_notes_link) { ?>
					<p class="s-byline-notes s-byline">
						<a class="download-sermon-notes download-link" href="<?php echo $cpt_sermon_meta_main_notes_link; ?>" title="Download sermon notes">Sermon notes</a> 
					</p>
					<?php } ?>
				</header>
				
				<?php
					/* NO VIDEO ON WIDGET LISTS
					if ($cpt_sermon_meta_video) {
				?>
					<div class="s-video">
						<?php echo $cpt_sermon_meta_video; ?>
					</div>
				<?php
					}
					*/
				?>
			
				<div class="st-summary s-summary s-content p-content">
					<?php // the_excerpt(); ?>
					<span class="clear"></span>
					<a class="s-more-link more-link p-permalink" href="<?php the_permalink(); ?>" title="Permalink to this post.">More &rarr;</a>
					<?php //edit_post_link('Edit'); ?>
				</div>
			
				<footer class="st-meta s-meta p-meta">
					<?php if (has_tag()) { ?>
					<p class="p-meta-block">
						<span class="meta-label">Tags</span>
						<?php the_tags('', ', '); ?>
					</p>
					<?php } ?>
					
					<span class="clear"></span>
				</footer>
			</section>
			

		<?php endwhile; ?>

		<?php echo $after_widget; ?>
<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_recent_sermons', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_recent_sermon_entries']) )
			delete_option('widget_recent_sermon_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_recent_sermons', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$number = isset($instance['number']) ? absint($instance['number']) : 5;
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of sermons to show:'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}


/* WIDGET: Display recent posts
   - This overrides the WP default function and displays
     custom markup and extra content.
*/

unregister_widget('WP_Widget_Recent_Posts');

add_action('widgets_init', create_function('',"register_widget('WP_Widget_Recent_Posts_Override');"));

class WP_Widget_Recent_Posts_Override extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_recent_entries', 'description' => __( "The most recent posts on your site") );
		parent::__construct('recent-posts', __('Recent Posts'), $widget_ops);
		$this->alt_option_name = 'widget_recent_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_recent_posts', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts') : $instance['title'], $instance, $this->id_base);
		if ( ! $number = absint( $instance['number'] ) )
 			$number = 10;

		$r = new WP_Query(array('posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true));
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>

		<?php  while ($r->have_posts()) : $r->the_post(); ?>
			
			<article class="t-small-post">
				<header class="ps-header">
					<h1 class="ps-title"><a class="p-title-link" href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h1>
					<p class="ps-header-meta">
						<span class="ps-byline p-byline">By <strong class="p-author"><?php the_author_posts_link(); ?></strong></span>
						<time class="ps-publish-date p-publish-date" datetime="<?php the_time('Y-m-d'); ?>" pubdate><?php the_time('M d, Y'); ?></time>
					</p>
				</header>
				
				<div class="ps-summary">
					<?php the_excerpt(); ?>
					<span class="clear"></span>
					<?php //edit_post_link('Edit'); ?>
				</div>
				
				<footer class="ps-meta">
					<p class="ps-meta-block">
						<a class="more-link" href="<?php the_permalink(); ?>" title="Permalink to this post.">More &rarr;</a>
					</p>
					
					<?php /* REMOVED FOR NOW. -DAY, 2011-09-19
						if (comments_open()) {
					?>
						<p class="ps-meta-block">
							<?php comments_popup_link('Leave a comment', '1 Comment', '% Comments'); ?>
						</p>
					<?php
						} */
					?>
		
					<span class="clear"></span>
				</footer>
			</article>
			
		<?php endwhile; ?>

		<?php echo $after_widget; ?>
<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_recent_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_recent_entries']) )
			delete_option('widget_recent_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_recent_posts', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$number = isset($instance['number']) ? absint($instance['number']) : 5;
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}

?>