<?php
/*
  The ideas, markup and code below are a mashup of the 
  Twenty Ten theme (2010 default WordPress theme),
  HTML5 Boilerplate (html5boilerplate.com/) and my
  professional expertise & preferences.
*/
?>

<!DOCTYPE html>

<!-- See here for explanation of below:
     paulirish.com/2008/conditional-stylesheets-vs-css-hacks-answer-neither/ -->
  
<!--[if lt IE 7 ]> <html lang="en" class="no-js ie6"> <![endif]-->
<!--[if IE 7 ]>    <html lang="en" class="no-js ie7"> <![endif]-->
<!--[if IE 8 ]>    <html lang="en" class="no-js ie8"> <![endif]-->
<!--[if IE 9 ]>    <html lang="en" class="no-js ie9"> <![endif]-->
<!--[if (gt IE 9)|!(IE)]><!--> <html lang="en" class="no-js"> <!--<![endif]-->

<head>	
  <meta charset="UTF-8" />
	
<?php
	/* --------
	   MOBILE FRIENDLY META
	   --------
	*/
?>

	<!-- For mobile devices and tablets. -->
	<meta name="viewport" content="width=device-width, initial-scale=1" />
	
<?php
	/* --------
	   SEARCH ENGINE OPTIMIZATION:
	   - Methods and functions for SEO are taken from the Twenty Eleven theme 
	     by WordPress and the Thematic theme by Ian Stewart.
	     
	     Twenty Eleven:  http://theme.wordpress.com/themes/twentyeleven/
	     Thematic:       http://themeshaper.com/thematic/
	   --------
	*/
?>
  <title>
    <?php
    	/* Displays a contextual title */
    	
      global $page, $paged;
      wp_title('|', true, 'right');
      
      // Add the blog name.
      bloginfo('name');

      // Add the blog description for the home/front page.
      $site_description = get_bloginfo('description', 'display');
      if ($site_description && (is_home() || is_front_page()))
        echo " | $site_description";

      // Add a page number if necessary:
      if ($paged >= 2 || $page >= 2)
        echo ' | ' . sprintf('Page %s', max($paged, $page));
    ?>
  </title>
	
	<?php
		// META DESCRIPTION 
		// NOTE: $site_description is from the above <title> section
		
		if((is_home() && ($paged < 2)) || is_front_page()) {
	?>
			<meta name="description" content="<?php echo esc_attr_e($site_description); ?>" />
	<?php
		}
		elseif (is_single() || is_page() || is_attachment()) {
	?>
			<meta name="description" content="<?php echo esc_attr_e($site_description); ?>" />
	<?php
		}
		elseif (is_tax('cpt_sermon_series')) {
	?>
			<meta name="description" content="<?php bloginfo('name'); ?> sermon series archives for <?php single_cat_title(); ?>" />
	<?php
		}
		elseif (is_tax('cpt_bible_books')) {
	?>
			<meta name="description" content="<?php bloginfo('name'); ?> archives for the book of <?php single_cat_title(); ?>" />
	<?php
		}
		elseif (is_search()) {
			echo '<meta name="description" content="Results for ' . get_search_query() . '" />';
		}
		else {	
			echo '<meta name="description" content="' . $site_description . '" />';
		}
		
		// CANONICAL URL
		if (is_singular()) {
			echo '<link rel="canonical" href="' . get_permalink() . '" />';
		}
		
		// SEARCH ENGINE BOTS
		if((is_home() && ($paged < 2)) || is_front_page() || is_single() || is_page() || is_attachment() || is_tax('cpt_sermon_series') || is_tax('cpt_bible_books')) {
			echo '<meta name="robots" content="index,follow" />';
		}
		elseif (is_search()) {
			echo '<meta name="robots" content="noindex,nofollow" />';
		}
		else {	
			echo '<meta name="robots" content="noindex,follow" />';
		}
  ?>

  <script src="<?php bloginfo('template_directory'); ?>/js/modernizr-latest.js"></script>
  <script src="<?php bloginfo('template_directory'); ?>/js/jquery-latest.js"></script>
  <script src="<?php bloginfo('template_directory'); ?>/js/cpt-ui.js"></script>
  
  <link rel="stylesheet" media="all" href="<?php bloginfo('stylesheet_url'); ?>" />
  <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>" />
  
  <?php
		// If using threaded comments
		if (is_singular() && get_option('thread_comments'))
			wp_enqueue_script('comment-reply');
		
		// Common hook for plugins; for many required.
		wp_head();
	?>
	
	<?php
		// Access our theme options
		$options = get_option('cpt_theme_options');
		
		$cpt_info_logo_upload_path = $options['cpt_info_logo_upload'];
		$cpt_sm_facebook_display = $options['cpt_sm_facebook_display'];
		$cpt_sm_twitter_display = $options['cpt_sm_twitter_display'];
		$cpt_sm_vimeo_display = $options['cpt_sm_vimeo_display'];
		$cpt_sm_flickr_display = $options['cpt_sm_flickr_display'];
		$cpt_sm_youtube_display = $options['cpt_sm_youtube_display'];
		$cpt_sm_rss_display = $options['cpt_sm_rss_display'];
		$cpt_sm_podcast_display = $options['cpt_sm_podcast_display'];
		
		$cpt_disp_home_msg = $options['cpt_disp_home_msg'];
		$cpt_home_msg = $options['cpt_home_msg'];
		$cpt_disable_home_msg = $options['cpt_disable_home_msg'];
	?>
	
	<?php
		// Get custom CSS if it exists
		$cpt_custom_styles = $options['cpt_custom_styles'];
		if ($cpt_custom_styles) {
			echo '<style>' . $cpt_custom_styles . '</style>';
		}
		
		// Output Google Analytics code if it exists		
		$cpt_ga_embed = $options['cpt_google_analytics_embed'];
		if ($cpt_ga_embed) {
			echo $cpt_ga_embed;
		}
	?>
</head>

<body <?php body_class(); ?>>
		
<div class="site">
<div class="site-frame">
	<div class="main-header">
  <header class="identity">
  	<?php
  		if ($cpt_info_logo_upload_path) {
  	?>
  		<a class="site-logo-image-link site-logo-link" href="<?php bloginfo('url'); ?>"><img class="site-logo-image" src="<?php echo $cpt_info_logo_upload_path; ?>" alt="<?php bloginfo('name'); ?>" /></a>
  	<?php
	  	}
	  	else {
  	?>
  		<hgroup class="site-logo-group">
  			<h1 class="site-logo-text"><a class="site-logo-link" href="<?php bloginfo('url'); ?>"><?php bloginfo('name'); ?></a></h1>
  			<h2 class="site-tagline"><?php bloginfo('description'); ?></h2>
  		</hgroup>
  	<?php
  		}
  	?>

    <?php get_search_form(); ?>
    
    <nav class="main-nav">
    	<ul class="main-nav-list">
    		<?php wp_list_pages('title_li=&depth=1&sort_column=menu_order'); ?>
    	</ul>
    	
    	<span class="clear"></span>
    </nav>
    
		<nav class="main-nav mobile-main-nav">
			<?php
				// Special thanks to: http://interstice.biz/wp_dropdown_pages-without-submit-button/
				$select_pages = wp_dropdown_pages('show_option_none=Select%20a%20page&depth=0&sort_column=menu_order&name=permalink&echo=0');
				$select_pages = preg_replace('#<select([^>]*)>#', '<select$1 onchange="location.href=\'' . get_bloginfo('url') . '/?page_id=\'+' . 'this.options[this.selectedIndex].value;">', $select_pages);
				echo $select_pages;
			?> 
		</nav>
		
		<ul class="social-media-icons">
			<?php if ($cpt_sm_facebook_display == "active") { ?>
			<li class="social-media-icon"><a class="social-media-icon-link" href="<?php echo $options['cpt_sm_facebook_handle']; ?>"><img src="<?php bloginfo('template_directory'); ?>/images/facebook-24x24.png" width="24" height="24" alt="Facebook" /></a></li>
			<?php } ?>
			<?php if ($cpt_sm_twitter_display == "active") { ?>
			<li class="social-media-icon"><a class="social-media-icon-link" href="http://twitter.com/<?php echo $options['cpt_sm_twitter_handle']; ?>"><img src="<?php bloginfo('template_directory'); ?>/images/twitter-24x24.png" width="24" height="24" alt="Twitter" /></a></li>
			<?php } ?>
			<?php if ($cpt_sm_vimeo_display == "active") { ?>
			<li class="social-media-icon"><a class="social-media-icon-link" href="<?php echo $options['cpt_sm_vimeo_handle']; ?>"><img src="<?php bloginfo('template_directory'); ?>/images/vimeo-24x24.png" width="24" height="24" alt="Vimeo" /></a></li>
			<?php } ?>
			<?php if ($cpt_sm_flickr_display == "active") { ?>
			<li class="social-media-icon"><a class="social-media-icon-link" href="<?php echo $options['cpt_sm_flickr_handle']; ?>"><img src="<?php bloginfo('template_directory'); ?>/images/flickr-24x24.png" width="24" height="24" alt="Flickr" /></a></li>
			<?php } ?>
			<?php if ($cpt_sm_youtube_display == "active") { ?>
			<li class="social-media-icon"><a class="social-media-icon-link" href="<?php echo $options['cpt_sm_youtube_handle']; ?>"><img src="<?php bloginfo('template_directory'); ?>/images/youtube-24x24.png" width="24" height="24" alt="YouTube" /></a></li>
			<?php } ?>
			<?php
				if ($cpt_sm_rss_display == "active") {
					$cpt_custom_feed = $options['cpt_sm_rss_feed'];
					
					if ($cpt_custom_feed) {
			?>
						<li class="social-media-icon"><a class="social-media-icon-link" href="<?php echo $options['cpt_sm_rss_feed']; ?>"><img src="<?php bloginfo('template_directory'); ?>/images/feed-24x24.png" width="24" height="24" alt="RSS" /></a></li>
			<?php
					}
					else {
			?>
						<li class="social-media-icon"><a class="social-media-icon-link" href="<?php bloginfo('url'); ?>/feed/"><img src="<?php bloginfo('template_directory'); ?>/images/feed-24x24.png" width="24" height="24" alt="RSS" /></a></li>
			<?php
					}
				}
			?>
			<?php if ($cpt_sm_podcast_display == "active") { ?>
			<li class="social-media-icon"><a class="social-media-icon-link" href="<?php echo $options['cpt_sm_podcast_feed']; ?>"><img src="<?php bloginfo('template_directory'); ?>/images/itunes-24x24.png" width="24" height="24" alt="Podcast" /></a></li>
			<?php } ?>
		</ul>
      
    <span class="clear"></span>
  </header>
  </div>
  
  <div class="main">