<?php

/*
This is based on the theme-options.php code from ThemeShaper.
REF: http://themeshaper.com/2010/06/03/sample-theme-options/
*/

add_action('admin_init', 'cpt_options_init');
add_action('admin_menu', 'theme_options_add_page');

/* Init plugin options to white list our options */
function cpt_options_init() {
	register_setting('cpt_options', 'cpt_theme_options', 'theme_options_validate');
}

/**
 * Load up the menu page
 */
function theme_options_add_page() {
	add_theme_page('Theme Options', 'Theme Options', 'edit_theme_options', 'theme_options', 'theme_options_do_page');
}

/**
 * Create arrays for our select and radio options
 */
$sm_select_options = array(
	'disabled' => array(
		'value' => 'disabled',
		'label' => 'Hide icon (deactivate)'
	),
	'active' => array(
		'value' => 'active',
		'label' => 'Display icon on site'
	)
);


/* --------
   ADD MORE ALLOWED TAGS
   
   REF: http://wptheming.com/2011/05/options-framework-0-6/comment-page-1/#comment-6891
   --------
*/
  
function cpt_custom_html_filter($input) {
	global $allowedtags;
	
	$cpt_tags = array();
	$cpt_tags = $allowedtags; // duplicate $allowed tags
	
	$cpt_tags["iframe"] = array(
		"src" => array(),
		"height" => array(),
		"width" => array(),
		"frameborder" => array(),
		"allowfullscreen" => array()
	);
	
	$cpt_tags["object"] = array(
		"height" => array(),
		"width" => array()
	);
	
	$cpt_tags["param"] = array(
		"name" => array(),
		"value" => array()
	);
	
	$cpt_tags["embed"] = array(
		"src" => array(),
		"type" => array(),
		"allowfullscreen" => array(),
		"allowscriptaccess" => array(),
		"height" => array(),
		"width" => array()
	);
	
	$cpt_tags["script"] = array(
		"type" => array()
	);
	
	$output = wp_kses($input, $cpt_tags); // kses filter against new list of allowed tags
	
	return $output;
}

/**
 * Create the options page
 */
function theme_options_do_page() {
	global $sm_select_options;

	if (!isset($_REQUEST['settings-updated']))
		$_REQUEST['settings-updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . get_current_theme() . ' Options' . "</h2>"; ?>

		<?php if (false !== $_REQUEST['settings-updated']) : ?>
		<div class="updated fade"><p><strong>Options saved</strong></p></div>
		<?php endif; ?>
		
		<p>Need help? Visit the <a href="http://support.designintellection.com/"><strong>support center</strong></a>.</p>
		
		<form method="post" enctype="multipart/form-data" action="options.php">
			<?php settings_fields('cpt_options'); ?>
			<?php $options = get_option('cpt_theme_options'); ?>
			
			<ul class="to-tabs">
				<li class="to-tab"><a class="to-tab-active to-tab-link" href="#to-information">General</a></li>
				<li class="to-tab"><a class="to-tab-link" href="#to-social-media">Social Media</a></li>
				<li class="to-tab"><a class="to-tab-link" href="#to-locations">Location</a></li>
				<li class="to-tab"><a class="to-tab-link" href="#to-advanced">Advanced</a></li>
			</ul>
			
			<div id="to-information" class="to-panel">
				<?php
					// Set null values if they don't exist
					$cpt_info_logo_upload = isset($options['cpt_info_logo_upload']) ? ($options['cpt_info_logo_upload']) : '';
					
					$cpt_info_primary_email = isset($options['cpt_info_primary_email']) ? ($options['cpt_info_primary_email']) : '';
					$cpt_info_phone = isset($options['cpt_info_phone']) ? ($options['cpt_info_phone']) : '';
					
					$cpt_google_calendar_embed = isset($options['cpt_google_calendar_embed']) ? ($options['cpt_google_calendar_embed']) : '';
					
					$cpt_disp_home_msg = isset($options['cpt_disp_home_msg']) ? ($options['cpt_disp_home_msg']) : '';
					$cpt_home_msg = isset($options['cpt_home_msg']) ? ($options['cpt_home_msg']) : '';
					$cpt_disable_home_all = isset($options['cpt_disable_home_all']) ? ($options['cpt_disable_home_all']) : '';
				?>
				
				<table class="form-table">
					<?php
						/* --------
						   CHURCH LOGO
						   --------
						*/
					?>
					<tr valign="top">
						<th scope="row">Upload Logo</th>
						<td>
							<label class="description" for="cpt_theme_options[cpt_info_logo_upload]">Upload an image (PNG, JPG or GIF) or paste in the URL.</label>
							<input id="cpt_info_logo_upload" class="cpt-file-upload" type="text" size="36" name="cpt_theme_options[cpt_info_logo_upload]" value="<?php esc_attr_e($cpt_info_logo_upload); ?>" />
							<input id="cpt_info_logo_upload_button" class="cpt-file-upload-button" type="button" value="Upload Image" />
							<p class="cpt-microcopy">The maximum width is 700px, there is no maximum height. <br/>For horizontal logos a height of 70-110px is recommended. <br/>For vertical logos a width of 140px is recommended.</p>
						</td>
					</tr>
					
					<?php
						/* --------
						   CHURCH CONTACT INFO
						   --------
						*/
					?>
					<tr valign="top">
						<th scope="row">Contact Information <span class="cpt-microcopy">Appears in footer and on Locations&nbsp;page</span></th>
						<td>
							<label class="description" for="cpt_theme_options[cpt_info_primary_email]">Primary Contact Email</label>
							<input id="cpt_theme_options[cpt_info_primary_email]" class="regular-text" type="text" name="cpt_theme_options[cpt_info_primary_email]" value="<?php esc_attr_e($cpt_info_primary_email); ?>" />
							
							<label class="description" for="cpt_theme_options[cpt_info_phone]">Phone Number</label>
							<input id="cpt_theme_options[cpt_info_phone]" class="regular-text" type="text" name="cpt_theme_options[cpt_info_phone]" value="<?php esc_attr_e($cpt_info_phone); ?>" />
						</td>
					</tr>
					
					<?php
						/* --------
						   GOOGLE CALENDAR EMBED
						   --------
						*/
					?>
					<tr valign="top">
						<th scope="row">Google Calendar Embed <span class="cpt-microcopy"></span></th>
						<td>
							<label class="description" for="cpt_theme_options[cpt_google_calendar_embed]">Paste the Google Calendar embed code below<span class="cpt-microcopy"></span></label>						
							<textarea id="cpt_theme_options[cpt_google_calendar_embed]" class="large-text" cols="50" rows="5" name="cpt_theme_options[cpt_google_calendar_embed]"><?php echo stripslashes($cpt_google_calendar_embed); ?></textarea>
						</td>
					</tr>
					
					<?php
						/* --------
						   BILLBOARDS/TAGLINES
						   --------
						*/
					?>
					
					<tr valign="top">
						<th scope="row">Homepage Billboard Area <span class="cpt-microcopy"></span></th>
						<td>
							<label for="cpt_theme_options[cpt_disp_home_msg]">
								<input id="cpt_theme_options[cpt_disp_home_msg]" name="cpt_theme_options[cpt_disp_home_msg]" type="checkbox" value="cpt_display_msg"<?php if ($cpt_disp_home_msg) echo ' checked="checked"'; ?> />
								<strong>Disable billboard slide show and display the message below.</strong>
							</label>
							
							<label class="description" for="cpt_theme_options[cpt_home_msg]"><span class="cpt-microcopy">(This is displayed fairly large on the home page.)</span></label>						
							<textarea id="cpt_theme_options[cpt_home_msg]" class="large-text" cols="50" rows="3" name="cpt_theme_options[cpt_home_msg]"><?php echo stripslashes($cpt_home_msg); ?></textarea>
							
							<label for="cpt_theme_options[cpt_disable_home_all]">
								<input id="cpt_theme_options[cpt_disable_home_all]" name="cpt_theme_options[cpt_disable_home_all]" type="checkbox" value="cpt_disable_all"<?php if ($cpt_disable_home_all) echo ' checked="checked"'; ?> />
								Disable billboard area entirely (this will hide everything, message above included).
							</label>
						</td>
					</tr>
				</table>
			</div>
			
			<div id="to-social-media" class="to-panel">
				
				<?php
					// Set null values if they don't exist
					$cpt_sm_facebook_handle = isset($options['cpt_sm_facebook_handle']) ? ($options['cpt_sm_facebook_handle']) : '';
					$cpt_sm_twitter_handle = isset($options['cpt_sm_twitter_handle']) ? ($options['cpt_sm_twitter_handle']) : '';
					$cpt_sm_vimeo_handle = isset($options['cpt_sm_vimeo_handle']) ? ($options['cpt_sm_vimeo_handle']) : '';
					$cpt_sm_flickr_handle = isset($options['cpt_sm_flickr_handle']) ? ($options['cpt_sm_flickr_handle']) : '';
					$cpt_sm_youtube_handle = isset($options['cpt_sm_youtube_handle']) ? ($options['cpt_sm_youtube_handle']) : '';
					$cpt_sm_rss_feed = isset($options['cpt_sm_rss_feed']) ? ($options['cpt_sm_rss_feed']) : '';
					$cpt_sm_podcast_feed = isset($options['cpt_sm_podcast_feed']) ? ($options['cpt_sm_podcast_feed']) : '';
				?>
				
				<table class="form-table">
				
					<?php
						/* --------
						   FACEBOOK
						   --------
						*/
					?>
					<tr valign="top">
						<th scope="row">Facebook</th>
						<td>
							<label class="description" for="cpt_theme_options[cpt_sm_facebook_handle]">Facebook website address:</label>
							<input id="cpt_theme_options[cpt_sm_facebook_handle]" class="regular-text" type="text" name="cpt_theme_options[cpt_sm_facebook_handle]" value="<?php esc_attr_e($cpt_sm_facebook_handle); ?>" />
							
							<select name="cpt_theme_options[cpt_sm_facebook_display]">
								<?php
									$selected = $options['cpt_sm_facebook_display'];
									$p = '';
									$r = '';
								
									foreach ($sm_select_options as $option) {
										$label = $option['label'];
										if ($selected == $option['value']) // Make default first in list
											$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr($option['value']) . "'>$label</option>";
										else
											$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr($option['value']) . "'>$label</option>";
									}
									echo $p . $r;
								?>
							</select>
						</td>
					</tr>
					
					<?php
						/* --------
						   TWITTER
						   --------
						*/
					?>
					
					<tr valign="top">
						<th scope="row">Twitter</th>
						<td>
							<label class="description" for="cpt_theme_options[cpt_sm_twitter_handle]">Twitter Username:</label>
							<strong class="twitter-helper">@</strong><input id="cpt_theme_options[cpt_sm_twitter_handle]" class="regular-text" type="text" name="cpt_theme_options[cpt_sm_twitter_handle]" value="<?php esc_attr_e($cpt_sm_twitter_handle); ?>" />
							
							<select name="cpt_theme_options[cpt_sm_twitter_display]">
								<?php
									$selected = $options['cpt_sm_twitter_display'];
									$p = '';
									$r = '';
								
									foreach ($sm_select_options as $option) {
										$label = $option['label'];
										if ($selected == $option['value']) // Make default first in list
											$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr($option['value']) . "'>$label</option>";
										else
											$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr($option['value']) . "'>$label</option>";
									}
									echo $p . $r;
								?>
							</select>
						</td>
					</tr>
					
					
					<?php
						/* --------
						   VIMEO
						   --------
						*/
					?>
					
					<tr valign="top">
						<th scope="row">Vimeo</th>
						<td>
							<label class="description" for="cpt_theme_options[cpt_sm_vimeo_handle]">Vimeo website address:</label>
							<input id="cpt_theme_options[cpt_sm_vimeo_handle]" class="regular-text" type="text" name="cpt_theme_options[cpt_sm_vimeo_handle]" value="<?php esc_attr_e($cpt_sm_vimeo_handle); ?>" />
							
							<select name="cpt_theme_options[cpt_sm_vimeo_display]">
								<?php
									$selected = $options['cpt_sm_vimeo_display'];
									$p = '';
									$r = '';
								
									foreach ($sm_select_options as $option) {
										$label = $option['label'];
										if ($selected == $option['value']) // Make default first in list
											$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr($option['value']) . "'>$label</option>";
										else
											$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr($option['value']) . "'>$label</option>";
									}
									echo $p . $r;
								?>
							</select>
						</td>
					</tr>
					
					
					<?php
						/* --------
						   FLICKR
						   --------
						*/
					?>

					<tr valign="top">
						<th scope="row">Flickr</th>
						<td>
							<label class="description" for="cpt_theme_options[cpt_sm_flickr_handle]">Flickr website address:</label>
							<input id="cpt_theme_options[cpt_sm_flickr_handle]" class="regular-text" type="text" name="cpt_theme_options[cpt_sm_flickr_handle]" value="<?php esc_attr_e($cpt_sm_flickr_handle); ?>" />
							
							<select name="cpt_theme_options[cpt_sm_flickr_display]">
								<?php
									$selected = $options['cpt_sm_flickr_display'];
									$p = '';
									$r = '';
								
									foreach ($sm_select_options as $option) {
										$label = $option['label'];
										if ($selected == $option['value']) // Make default first in list
											$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr($option['value']) . "'>$label</option>";
										else
											$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr($option['value']) . "'>$label</option>";
									}
									echo $p . $r;
								?>
							</select>
						</td>
					</tr>
					
					<?php
						/* --------
						   YOUTUBE
						   --------
						*/
					?>

					<tr valign="top">
						<th scope="row">YouTube</th>						
						<td>
							<label class="description" for="cpt_theme_options[cpt_sm_youtube_handle]">YouTube website address:</label>
							<input id="cpt_theme_options[cpt_sm_youtube_handle]" class="regular-text" type="text" name="cpt_theme_options[cpt_sm_youtube_handle]" value="<?php esc_attr_e($cpt_sm_youtube_handle); ?>" />
							
							<select name="cpt_theme_options[cpt_sm_youtube_display]">
								<?php
									$selected = $options['cpt_sm_youtube_display'];
									$p = '';
									$r = '';
								
									foreach ($sm_select_options as $option) {
										$label = $option['label'];
										if ($selected == $option['value']) // Make default first in list
											$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr($option['value']) . "'>$label</option>";
										else
											$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr($option['value']) . "'>$label</option>";
									}
									echo $p . $r;
								?>
							</select>
						</td>
					</tr>
					
					<?php
						/* --------
						   RSS
						   --------
						*/
					?>

					<tr valign="top">
						<th scope="row">RSS</th>
						<td>
							<label class="description" for="cpt_theme_options[cpt_sm_rss_feed]">Feedburner link (or other alternate RSS feed address) <span class="cpt-microcopy">If you leave the input blank but display the icon it will use the default WordPress blog feed.</span></label>
							<input id="cpt_theme_options[cpt_sm_rss_feed]" class="regular-text" type="text" name="cpt_theme_options[cpt_sm_rss_feed]" value="<?php esc_attr_e($cpt_sm_rss_feed); ?>" />
							
							<select name="cpt_theme_options[cpt_sm_rss_display]">
								<?php
									$selected = $options['cpt_sm_rss_display'];
									$p = '';
									$r = '';
								
									foreach ($sm_select_options as $option) {
										$label = $option['label'];
										if ($selected == $option['value']) // Make default first in list
											$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr($option['value']) . "'>$label</option>";
										else
											$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr($option['value']) . "'>$label</option>";
									}
									echo $p . $r;
								?>
							</select>
						</td>
					</tr>
					
					<?php
						/* --------
						   PODCAST ITUNES LINK
						   --------
						*/
					?>

					<tr valign="top">
						<th scope="row">Podcast</th>
						<td>
							<label class="description" for="cpt_theme_options[cpt_sm_podcast_feed]">iTunes podcast link</label>
							<input id="cpt_theme_options[cpt_sm_podcast_feed]" class="regular-text" type="text" name="cpt_theme_options[cpt_sm_podcast_feed]" value="<?php esc_attr_e($cpt_sm_podcast_feed); ?>" />
							
							<select name="cpt_theme_options[cpt_sm_podcast_display]">
								<?php
									$selected = $options['cpt_sm_podcast_display'];
									$p = '';
									$r = '';
								
									foreach ($sm_select_options as $option) {
										$label = $option['label'];
										if ($selected == $option['value']) // Make default first in list
											$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr($option['value']) . "'>$label</option>";
										else
											$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr($option['value']) . "'>$label</option>";
									}
									echo $p . $r;
								?>
							</select>
						</td>
					</tr>
					
				</table>
			</div>
			
			<div id="to-locations" class="to-panel">
			
			<?php
				// Set null values if they don't exist
				$cpt_loc_map_embed = isset($options['cpt_loc_map_embed']) ? ($options['cpt_loc_map_embed']) : '';
	
				$cpt_info_church_name = isset($options['cpt_info_church_name']) ? ($options['cpt_info_church_name']) : '';
				$cpt_info_address_1 = isset($options['cpt_info_address_1']) ? ($options['cpt_info_address_1']) : '';
				$cpt_info_address_2 = isset($options['cpt_info_address_2']) ? ($options['cpt_info_address_2']) : '';
				$cpt_info_city = isset($options['cpt_info_city']) ? ($options['cpt_info_city']) : '';
				$cpt_info_state = isset($options['cpt_info_state']) ? ($options['cpt_info_state']) : '';
				$cpt_info_zip = isset($options['cpt_info_zip']) ? ($options['cpt_info_zip']) : '';
			?>
				
			<table class="form-table">
				<?php
					/* --------
					   CHURCH ADDRESS
					   --------
					*/
				?>
				<tr valign="top">
					<th scope="row">Church Address <span class="cpt-microcopy">Appears in footer</span></th>						
					<td>
						<label class="description" for="cpt_theme_options[cpt_info_church_name]">Church Name</label>
						<input id="cpt_theme_options[cpt_info_church_name]" class="regular-text" type="text" name="cpt_theme_options[cpt_info_church_name]" value="<?php esc_attr_e($cpt_info_church_name); ?>" />
						
						<label class="description" for="cpt_theme_options[cpt_info_address_1]">Address 1</label>
						<input id="cpt_theme_options[cpt_info_address_1]" class="regular-text" type="text" name="cpt_theme_options[cpt_info_address_1]" value="<?php esc_attr_e($cpt_info_address_1); ?>" />
						
						<label class="description" for="cpt_theme_options[cpt_info_address_2]">Address 2</label>
						<input id="cpt_theme_options[cpt_info_address_2]" class="regular-text" type="text" name="cpt_theme_options[cpt_info_address_2]" value="<?php esc_attr_e($cpt_info_address_2); ?>" />

						<label class="description" for="cpt_theme_options[cpt_info_city]">City</label>
						<input id="cpt_theme_options[cpt_info_city]" class="cpt-med-input regular-text" type="text" name="cpt_theme_options[cpt_info_city]" value="<?php esc_attr_e($cpt_info_city); ?>" />
					
						<label class="description" for="cpt_theme_options[cpt_info_state]">State</label>
						<input id="cpt_theme_options[cpt_info_state]" class="cpt-sm-input regular-text" type="text" name="cpt_theme_options[cpt_info_state]" value="<?php esc_attr_e($cpt_info_state); ?>" />
					
						<label class="description" for="cpt_theme_options[cpt_info_zip]">Zip</label>
						<input id="cpt_theme_options[cpt_info_zip]" class="cpt-sm-input regular-text" type="text" name="cpt_theme_options[cpt_info_zip]" value="<?php esc_attr_e($cpt_info_zip); ?>" />
					</td>
				</tr>
					
				<?php
					/* --------
					   CHURCH GOOGLE MAP EMBED
					   --------
					*/
				?>
				<tr valign="top">
					<th scope="row">Locations Map <span class="cpt-microcopy"></span></th>
					<td>
						<label class="description" for="cpt_theme_options[cpt_loc_map_embed]">Google Maps Embed Code (or Yahoo, Bing, etc.) <span class="cpt-microcopy">Set dimensions to 536x306 pixels <a href="http://support.designintellection.com/kb/initial-setup/how-to-setup-a-custom-google-map-for-your-church">Need help?</a></span></label>						
						<textarea id="cpt_theme_options[cpt_loc_map_embed]" class="large-text" cols="50" rows="10" name="cpt_theme_options[cpt_loc_map_embed]"><?php echo stripslashes($cpt_loc_map_embed); ?></textarea>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row">Map Icon Paths <span class="cpt-microcopy">URLs for special map icons</span></th>
					<td>
						<strong class="map-icon-name">Main map icon</strong>
						<span class="map-icon-url"><?php echo get_bloginfo('template_directory') . '/images/icn-map-main.png'; ?></span>
						<strong class="map-icon-name">Community group map icon</strong>
						<span class="map-icon-url"><?php echo get_bloginfo('template_directory') . '/images/icn-map-cg.png'; ?></span>
					</td>
				</tr>
			</table>
			</div>
			
			<div id="to-advanced" class="to-panel">
			
			<?php
				// Set null values if they don't exist
				$cpt_google_analytics_embed = isset($options['cpt_google_analytics_embed']) ? ($options['cpt_google_analytics_embed']) : '';
				$cpt_custom_styles = isset($options['cpt_custom_styles']) ? ($options['cpt_custom_styles']) : '';
			?>

			<table class="form-table">
				<?php
					/* --------
					   GOOGLE ANALYTICS EMBED
					   --------
					*/
				?>
				<tr valign="top">
					<th scope="row">Google Analytics <span class="cpt-microcopy"></span></th>
					<td>
						<label class="description" for="cpt_theme_options[cpt_google_analytics_embed]">Google Analytics Embed Code <span class="cpt-microcopy">The theme automatically places this in the appropriate spot.</span></label>						
						<textarea id="cpt_theme_options[cpt_google_analytics_embed]" class="large-text" cols="50" rows="10" name="cpt_theme_options[cpt_google_analytics_embed]"><?php echo stripslashes($cpt_google_analytics_embed); ?></textarea>
					</td>
				</tr>
				
				<?php
					/* --------
					   CUSTOM CSS STYLES
					   --------
					*/
				?>
				<tr valign="top">
					<th scope="row">Custom Styles <span class="cpt-microcopy"></span></th>
					<td>
						<label class="description" for="cpt_theme_options[cpt_custom_styles]">Add custom CSS below <span class="cpt-microcopy">The CSS is output between &lt;style&gt; tags in the &lt;head&gt;. This is mainly here for your convenience and minor style changes. If you are creating extensive design changes it&#8217;s better to do that with a child theme. <!--(<a href="#">See instructions here</a>.)--></span></label>						
						<textarea id="cpt_theme_options[cpt_custom_styles]" class="large-text" cols="50" rows="10" name="cpt_theme_options[cpt_custom_styles]"><?php echo stripslashes($cpt_custom_styles); ?></textarea>
					</td>
				</tr>
			</table>
			</div>
			
			<p class="submit">
				<input type="submit" class="button-primary" value="Save options" />
			</p>
		</form>
	</div>
	
	<script>
		/* This function enables the panel switching when the tabs are clicked. */
		
		// Avoids conflicts
		$cpt_jQuery = jQuery.noConflict();
		
		$cpt_jQuery("#to-information").show();

		$cpt_jQuery(".to-tabs a").click(function() {
			var panel_target = $cpt_jQuery(this).attr("href");

			$cpt_jQuery(".to-tabs a").removeClass("to-tab-active");
			$cpt_jQuery(this).addClass("to-tab-active");
			$cpt_jQuery(".to-panel").hide();
			$cpt_jQuery(panel_target).show();
			
			return false;
		});
	</script>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function theme_options_validate($input) {
	global $sm_select_options;
	
	// Our checkbox value is either 0 or 1
	/*if (!isset($input['option1']))
		$input['option1'] = null;
	$input['option1'] = ($input['option1'] == 1 ? 1 : 0);*/
	
	// LOGO UPLOAD
	// This only saves the URI to the image. Everything else is handled 
	// via WordPress' media library/API. 
	$input['cpt_info_logo_upload'] = wp_filter_nohtml_kses($input['cpt_info_logo_upload']);
	
	$input['cpt_info_primary_email'] = wp_filter_nohtml_kses($input['cpt_info_primary_email']);
	$input['cpt_info_phone'] = wp_filter_nohtml_kses($input['cpt_info_phone']);
	$input['cpt_info_church_name'] = wp_filter_nohtml_kses($input['cpt_info_church_name']);
	$input['cpt_info_address_1'] = wp_filter_nohtml_kses($input['cpt_info_address_1']);
	$input['cpt_info_address_2'] = wp_filter_nohtml_kses($input['cpt_info_address_2']);
	$input['cpt_info_city'] = wp_filter_nohtml_kses($input['cpt_info_city']);
	$input['cpt_info_state'] = wp_filter_nohtml_kses($input['cpt_info_state']);
	$input['cpt_info_zip'] = wp_filter_nohtml_kses($input['cpt_info_zip']);
	
	$input['cpt_sm_facebook_handle'] = wp_filter_nohtml_kses($input['cpt_sm_facebook_handle']);
	$input['cpt_sm_twitter_handle'] = wp_filter_nohtml_kses($input['cpt_sm_twitter_handle']);
	$input['cpt_sm_vimeo_handle'] = wp_filter_nohtml_kses($input['cpt_sm_vimeo_handle']);
	$input['cpt_sm_flickr_handle'] = wp_filter_nohtml_kses($input['cpt_sm_flickr_handle']);
	$input['cpt_sm_youtube_handle'] = wp_filter_nohtml_kses($input['cpt_sm_youtube_handle']);
	$input['cpt_sm_rss_feed'] = wp_filter_nohtml_kses($input['cpt_sm_rss_feed']);
	$input['cpt_sm_podcast_feed'] = wp_filter_nohtml_kses($input['cpt_sm_podcast_feed']);
	
	// Our select option must actually be in our array of select options
	if (!array_key_exists($input['cpt_sm_facebook_display'], $sm_select_options))
		$input['cpt_sm_facebook_display'] = null;
	if (!array_key_exists($input['cpt_sm_twitter_display'], $sm_select_options))
		$input['cpt_sm_twitter_display'] = null;
	if (!array_key_exists($input['cpt_sm_vimeo_display'], $sm_select_options))
		$input['cpt_sm_vimeo_display'] = null;
	if (!array_key_exists($input['cpt_sm_flickr_display'], $sm_select_options))
		$input['cpt_sm_flickr_display'] = null;
	if (!array_key_exists($input['cpt_sm_rss_display'], $sm_select_options))
		$input['cpt_sm_rss_display'] = null;
	if (!array_key_exists($input['cpt_sm_podcast_display'], $sm_select_options))
		$input['cpt_sm_podcast_display'] = null;

	// Say our textarea option must be safe text with the allowed tags for posts
	$input['cpt_google_calendar_embed'] = cpt_custom_html_filter($input['cpt_google_calendar_embed']);
	$input['cpt_home_msg'] = cpt_custom_html_filter($input['cpt_home_msg']);
	$input['cpt_loc_map_embed'] = cpt_custom_html_filter($input['cpt_loc_map_embed']);
	$input['cpt_google_analytics_embed'] = cpt_custom_html_filter($input['cpt_google_analytics_embed']);
	$input['cpt_custom_styles'] = cpt_custom_html_filter($input['cpt_custom_styles']);

	return $input;
}

// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/